@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use boolean qw(true false);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub _parse_formatted_ymd
 {
@@ -14,19 +14,19 @@ sub _parse_formatted_ymd
     my $date = $self->_split_formatted($date_string);
 
     my $date_sep = quotemeta((keys %$count)[0]);
-    my @chunks = split /$date_sep/, $date;
+    my @date_chunks = split /$date_sep/, $date;
 
     my $i = 0;
-    my %length = map { length $_ => $i++ } @chunks;
+    my %chunks_length = map { length $_ => $i++ } @date_chunks;
 
     my $format = lc $self->{Format};
     my $format_sep;
 
     my $lax = false;
 
-    if (exists $length{4}) {
+    if (exists $chunks_length{4}) {
         $format = join $date_sep,
-          ($length{4} == 0
+          ($chunks_length{4} == 0
             ? qw(yyyy mm dd)
             : ($format =~ /^m/
                 ? qw(mm dd yyyy)
@@ -35,7 +35,7 @@ sub _parse_formatted_ymd
           );
         $lax = true;
     }
-    elsif ($date_sep =~ /^\\[-.]$/ and $format !~ /$date_sep/) {
+    elsif ($date_sep =~ /^\\[-.]$/ && $format !~ /$date_sep/) {
         $format = join $date_sep, qw(dd mm yy);
         $lax = true;
     }
@@ -47,34 +47,32 @@ sub _parse_formatted_ymd
     }
     $format_sep ||= $date_sep;
 
-    if (not $lax and ($format_sep ne $date_sep)) {
+    if (!$lax && $format_sep ne $date_sep) {
         $self->_set_failure;
         $self->_set_error("(mismatch between format and date separator)");
         return $self->_get_datetime_object;
     }
 
-    my @separated_order = split /$format_sep/, $format;
+    my @format_order = split /$format_sep/, $format;
 
     my ($d, $m, $y) = do {
-        my %f = map { substr($_, 0, 1) => true } @separated_order;
+        my %f = map { substr($_, 0, 1) => true } @format_order;
         ($f{d}, $f{m}, $f{y});
     };
-    unless (@separated_order == 3 and ($d && $m && $y)) {
+    unless (@format_order == 3 and $d && $m && $y) {
         $self->_set_failure;
         $self->_set_error("('format' parameter invalid)");
         return $self->_get_datetime_object;
     }
 
-    my $separated_index = 0;
-    my $separated_indices = { map { substr($_, 0, 1) => $separated_index++ } @separated_order };
-
-    my @bits = split /$date_sep/, $date;
+    $i = 0;
+    my %format_index = map { substr($_, 0, 1) => $i++ } @format_order;
 
     my $century = $self->{datetime}
                 ? int($self->{datetime}->year / 100)
                 : substr((localtime)[5] + 1900, 0, 2);
 
-    my ($day, $month, $year) = map $bits[$separated_indices->{$_}], qw(d m y);
+    my ($day, $month, $year) = map $date_chunks[$format_index{$_}], qw(d m y);
 
     if (length $year == 2) { $year = "$century$year" };
 
